@@ -82,7 +82,7 @@ int client_send(unsigned char *buf, unsigned int len)
 	printf("< %s\n", buf);
 	while (haveWritten<len)
 	{
-		ret = write(sd, buf, len);
+		ret = write(sd, buf+haveWritten, len-haveWritten);
 		if (ret<0)
 		{
 			perror("Error on write - lost connection to tetrinet server?");
@@ -128,7 +128,7 @@ int client_receive(unsigned char *buf, unsigned int len)
 
 		}
 	}
-	return ret;
+	return haveRead;
 }
 
 int send_special(int to_player, const char *special, int from_player)
